@@ -208,6 +208,10 @@ class AdminService:
         check()
         return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
 
+    def RemoveUser(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).RemoveUser, request)
+
     def SetGlobalProperty(self, request):
         check()
         return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)
@@ -245,6 +249,12 @@ class AdminService:
     def GetGlobalPropertiesResponse(self, **kwargs):
         return admin_pb2.GetGlobalPropertiesResponse(**kwargs)
 
+    def RemoveUserRequest(self, **kwargs):
+        return admin_pb2.RemoveUserRequest(**kwargs)
+
+    def RemoveUserResponse(self, **kwargs):
+        return admin_pb2.RemoveUserResponse(**kwargs)
+
     def SetGlobalPropertyRequest(self, **kwargs):
         return admin_pb2.SetGlobalPropertyRequest(**kwargs)
 
